@@ -119,8 +119,11 @@ class Recipe(object):
     ))
     slave = options.get('slave', 'false').lower() in \
       librecipe.GenericBaseRecipe.TRUE_VALUES
+
     # By default XXXX Way of doing it is ugly and dangerous
     requested_state = options.get('state', buildout['slap-connection'].get('requested','started'))
+    options['requested-state'] = requested_state
+
     slap = slapmodule.slap()
     slap.initializeConnection(
       options['server-url'],
@@ -134,6 +137,7 @@ class Recipe(object):
     self._raise_request_exception = None
     self._raise_request_exception_formatted = None
     self.instance = None
+
     # Try to do the request and fetch parameter dict...
     try:
       self.instance = request(software_url, software_type,
@@ -141,14 +145,17 @@ class Recipe(object):
           filter_kw=filter_kw, shared=slave, state=requested_state)
       return_parameter_dict = self._getReturnParameterDict(self.instance,
           return_parameters)
+      # Fetch the instance-guid and the instance-state
+      # Note: SlapOS Master does not support it for slave instances
       if not slave:
         try:
           options['instance-guid'] = self.instance.getInstanceGuid()
           # XXX: deprecated, to be removed
           options['instance_guid'] = self.instance.getInstanceGuid()
+          options['instance-state'] = self.instance.getState()
         except (slapmodule.ResourceNotReady, AttributeError):
           # Backward compatibility. Old SlapOS master and core don't know this.
-          self.logger.warning("Impossible to fetch instance GUID.")
+          self.logger.warning("Impossible to fetch instance GUID nor state.")
     except (slapmodule.NotFoundError, slapmodule.ServerError, slapmodule.ResourceNotReady) as exc:
       self._raise_request_exception = exc
       self._raise_request_exception_formatted = traceback.format_exc()
@@ -162,13 +169,6 @@ class Recipe(object):
       except KeyError:
         if self.failed is None:
           self.failed = param
-    options['requested-state'] = requested_state
-    try:
-      options['instance-state'] = self.instance.getState()
-    except slapmodule.ResourceNotReady:
-       # Odd case: SlapOS Master doesn't send the state of a slave partition.
-       # XXX Should be fixed in the SlapOS Master, we should not care here.
-       pass
 
   def _filterForStorage(self, partition_parameter_kw):
     return partition_parameter_kw
